Learn R Programming

nser (version 1.6.0)

nseopenfo: NSE Derivatives Pre Open Market of current month's future stock.

Description

NSE Derivatives Pre Open Market of current month's future stock.

Usage

nseopenfo(x = "fo")

Value

A dataframe with Derivatives Pre Open Market of current month's future stock.

Arguments

x

"fo" for F&O stocks,

Author

Nandan L. Patil tryanother609@gmail.com

Details

Get Derivatives Pre Open Market of current month's future stock.

See Also

bhavprbhavfobhavtoday

Examples

Run this code
if (FALSE) {

# Pre open market data of Current Months Futures of F&O stocks
library(nser)
nseopenfo()
}

Run the code above in your browser using DataLab